[Bf-blender-cvs] [dfd9bfd] master: Spelling

Campbell Barton noreply at git.blender.org
Wed Aug 13 00:43:44 CEST 2014


Commit: dfd9bfd3a8ac8fef72d5547cdb7b0612f6ed6265
Author: Campbell Barton
Date:   Wed Aug 13 08:38:16 2014 +1000
Branches: master
https://developer.blender.org/rBdfd9bfd3a8ac8fef72d5547cdb7b0612f6ed6265

Spelling

===================================================================

M	intern/cycles/blender/blender_mesh.cpp
M	intern/ghost/intern/GHOST_SystemWin32.cpp
M	intern/ghost/intern/GHOST_WindowX11.h
M	source/blender/editors/interface/interface_handlers.c
M	source/blender/editors/space_view3d/view3d_camera_control.c
M	source/blender/editors/space_view3d/view3d_fly.c
M	source/blender/editors/space_view3d/view3d_intern.h
M	source/blender/editors/space_view3d/view3d_walk.c
M	source/blender/modifiers/intern/MOD_weightvgproximity.c
M	source/blender/python/intern/bpy_operator.c

===================================================================

diff --git a/intern/cycles/blender/blender_mesh.cpp b/intern/cycles/blender/blender_mesh.cpp
index f07f0fd..c2254f8 100644
--- a/intern/cycles/blender/blender_mesh.cpp
+++ b/intern/cycles/blender/blender_mesh.cpp
@@ -560,7 +560,7 @@ Mesh *BlenderSync::sync_mesh(BL::Object b_ob, bool object_updated, bool hide_tri
 	vector<Mesh::Triangle> oldtriangle = mesh->triangles;
 	
 	/* compares curve_keys rather than strands in order to handle quick hair
-	 * adjustsments in dynamic BVH - other methods could probably do this better*/
+	 * adjustments in dynamic BVH - other methods could probably do this better*/
 	vector<float4> oldcurve_keys = mesh->curve_keys;
 
 	mesh->clear();
diff --git a/intern/ghost/intern/GHOST_SystemWin32.cpp b/intern/ghost/intern/GHOST_SystemWin32.cpp
index cad2aab..ca2768e 100644
--- a/intern/ghost/intern/GHOST_SystemWin32.cpp
+++ b/intern/ghost/intern/GHOST_SystemWin32.cpp
@@ -1439,9 +1439,7 @@ static bool isStartedFromCommandPrompt()
 			}
 		}
 
-		/* When we're starting from a wrapper we need to comare with
-		 * parent process ID.
-		 */
+		/* When we're starting from a wrapper we need to compare with parent process ID. */
 		if (pid == (start_from_launcher ? ppid : GetCurrentProcessId()))
 			return true;
 	}
diff --git a/intern/ghost/intern/GHOST_WindowX11.h b/intern/ghost/intern/GHOST_WindowX11.h
index afe21b0..faaa05e 100644
--- a/intern/ghost/intern/GHOST_WindowX11.h
+++ b/intern/ghost/intern/GHOST_WindowX11.h
@@ -279,7 +279,7 @@ protected:
 	/**
 	 * Sets the cursor grab on the window using
 	 * native window system calls.
-	 * \param warp	Only used when grab is enabled, hides the mouse and allows gragging outside the screen.
+	 * \param warp	Only used when grab is enabled, hides the mouse and allows dragging outside the screen.
 	 */
 	GHOST_TSuccess
 	setWindowCursorGrab(
diff --git a/source/blender/editors/interface/interface_handlers.c b/source/blender/editors/interface/interface_handlers.c
index 3393861..7cc2145 100644
--- a/source/blender/editors/interface/interface_handlers.c
+++ b/source/blender/editors/interface/interface_handlers.c
@@ -154,7 +154,7 @@ typedef enum uiHandleButtonState {
  * note: half the height of a button is about right... */
 #define DRAG_MULTINUM_THRESHOLD_DRAG_X (UI_UNIT_Y / 4)
 
-/* how far to drag horizontally before we stop checkign which buttons the gesture spans (in pixels),
+/* how far to drag horizontally before we stop checking which buttons the gesture spans (in pixels),
  * locking down the buttons so we can drag freely without worrying about vertical movement. */
 #define DRAG_MULTINUM_THRESHOLD_DRAG_Y (UI_UNIT_Y / 4)
 
diff --git a/source/blender/editors/space_view3d/view3d_fly.c b/source/blender/editors/space_view3d/view3d_fly.c
index 6afe0ef..da77c4f 100644
--- a/source/blender/editors/space_view3d/view3d_fly.c
+++ b/source/blender/editors/space_view3d/view3d_fly.c
@@ -385,7 +385,7 @@ static bool initFlyInfo(bContext *C, FlyInfo *fly, wmOperator *op, const wmEvent
 		fly->zlock = FLY_AXISLOCK_STATE_IDLE;
 	}
 
-	fly->v3d_camera_control = ED_view3d_cameracontrol_aquire(
+	fly->v3d_camera_control = ED_view3d_cameracontrol_acquire(
 	        fly->scene, fly->v3d, fly->rv3d,
 	        (U.uiflag & USER_CAM_LOCK_NO_PARENT) == 0);
 
diff --git a/source/blender/editors/space_view3d/view3d_intern.h b/source/blender/editors/space_view3d/view3d_intern.h
index 169bc49..ab2292a 100644
--- a/source/blender/editors/space_view3d/view3d_intern.h
+++ b/source/blender/editors/space_view3d/view3d_intern.h
@@ -233,7 +233,7 @@ void VIEW3D_OT_properties(struct wmOperatorType *ot);
 void view3d_buttons_register(struct ARegionType *art);
 
 /* view3d_camera_control.c */
-struct View3DCameraControl *ED_view3d_cameracontrol_aquire(
+struct View3DCameraControl *ED_view3d_cameracontrol_acquire(
         Scene *scene, View3D *v3d, RegionView3D *rv3d,
         const bool use_parent_root);
 void ED_view3d_cameracontrol_update(
diff --git a/source/blender/editors/space_view3d/view3d_walk.c b/source/blender/editors/space_view3d/view3d_walk.c
index a9516e6..7bdf39d 100644
--- a/source/blender/editors/space_view3d/view3d_walk.c
+++ b/source/blender/editors/space_view3d/view3d_walk.c
@@ -538,7 +538,7 @@ static bool initWalkInfo(bContext *C, WalkInfo *walk, wmOperator *op)
 	walk->rv3d->rflag |= RV3D_NAVIGATING;
 
 
-	walk->v3d_camera_control = ED_view3d_cameracontrol_aquire(
+	walk->v3d_camera_control = ED_view3d_cameracontrol_acquire(
 	        walk->scene, walk->v3d, walk->rv3d,
 	        (U.uiflag & USER_CAM_LOCK_NO_PARENT) == 0);
 
diff --git a/source/blender/modifiers/intern/MOD_weightvgproximity.c b/source/blender/modifiers/intern/MOD_weightvgproximity.c
index 010fe1d..71d4742 100644
--- a/source/blender/modifiers/intern/MOD_weightvgproximity.c
+++ b/source/blender/modifiers/intern/MOD_weightvgproximity.c
@@ -72,9 +72,9 @@ static void get_vert2geom_distance(int numVerts, float (*v_cos)[3],
                                    DerivedMesh *target, const SpaceTransform *loc2trgt)
 {
 	int i;
-	BVHTreeFromMesh treeData_v = {0};
-	BVHTreeFromMesh treeData_e = {0};
-	BVHTreeFromMesh treeData_f = {0};
+	BVHTreeFromMesh treeData_v = {NULL};
+	BVHTreeFromMesh treeData_e = {NULL};
+	BVHTreeFromMesh treeData_f = {NULL};
 	BVHTreeNearest nearest_v   = {0};
 	BVHTreeNearest nearest_e   = {0};
 	BVHTreeNearest nearest_f   = {0};
diff --git a/source/blender/python/intern/bpy_operator.c b/source/blender/python/intern/bpy_operator.c
index 2c52660..1e97d7a 100644
--- a/source/blender/python/intern/bpy_operator.c
+++ b/source/blender/python/intern/bpy_operator.c
@@ -58,7 +58,7 @@
 #include "BKE_report.h"
 #include "BKE_context.h"
 
-/* so operators called can spawn threads which aquire the GIL */
+/* so operators called can spawn threads which acquire the GIL */
 #define BPY_RELEASE_GIL




More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/editors/space_view3d/view3d_camera_control.c b/source/blender/editors/space_view3d/view3d_camera_control.c
index e96db2b..ee0f3da1 100644
--- a/source/blender/editors/space_view3d/view3d_camera_control.c
+++ b/source/blender/editors/space_view3d/view3d_camera_control.c
@@ -31,9 +31,9 @@
  *
  * Typical view-control usage:
  *
- * - aquire a view-control (#ED_view3d_control_aquire).
+ * - acquire a view-control (#ED_view3d_control_acquire).
  * - modify ``rv3d->ofs``, ``rv3d->viewquat``.
  * - update the view data (#ED_view3d_control_aquire) - within a loop which draws the viewport.
  * - finish and release the view-control (#ED_view3d_control_release),
  *   either keeping the current view or restoring the initial view.
  *
@@ -138,7 +138,7 @@ Object *ED_view3d_cameracontrol_object_get(View3DCameraControl *vctrl)
  * Creates a #View3DControl handle and sets up
  * the view for first-person style navigation.
  */
-struct View3DCameraControl *ED_view3d_cameracontrol_aquire(
+struct View3DCameraControl *ED_view3d_cameracontrol_acquire(
         Scene *scene, View3D *v3d, RegionView3D *rv3d,
         const bool use_parent_root)
 {
@@ -282,7 +282,7 @@ void ED_view3d_cameracontrol_update(
  * Release view control.
  *
  * \param restore  Sets the view state to the values that were set
  *                 before #ED_view3d_control_aquire was called.
  */
 void ED_view3d_cameracontrol_release(
         View3DCameraControl *vctrl,
@@ -31,9 +31,9 @@
  * - modify ``rv3d->ofs``, ``rv3d->viewquat``.
- * - update the view data (#ED_view3d_control_aquire) - within a loop which draws the viewport.
+ * - update the view data (#ED_view3d_control_acquire) - within a loop which draws the viewport.
  * - finish and release the view-control (#ED_view3d_control_release),
  *   either keeping the current view or restoring the initial view.
@@ -282,7 +282,7 @@ void ED_view3d_cameracontrol_update(
  *
  * \param restore  Sets the view state to the values that were set
- *                 before #ED_view3d_control_aquire was called.
+ *                 before #ED_view3d_control_acquire was called.
  */
 void ED_view3d_cameracontrol_release(